@@ -24,13 +24,14 @@
 #include <QFile>
 #include "libdiscover_debug.h"
 #include <QStandardPaths>
+#include <QCoreApplication>
 
 #include <DiscoverBackendsFactory.h>
 #include <resources/AbstractResourcesBackend.h>
 
 QVector<Category*> CategoriesReader::loadCategoriesFile(AbstractResourcesBackend* backend)
 {
-    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libdiscover/categories/")+backend->name()+QStringLiteral("-categories.xml"));
+    QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("libdiscover/categories/")+backend->name()+QLatin1String("-categories.xml"));
     if (path.isEmpty()) {
         auto cat = backend->category();
         if (cat.isEmpty())
@@ -64,7 +65,7 @@ QVector<Category*> CategoriesReader::loadCategoriesPath(const QString& path)
     while(!node.isNull())
     {
         if (node.nodeType() == QDomNode::ElementNode) {
-            ret << new Category( {path} );
+            ret << new Category( {path}, qApp );
             ret.last()->parseData(path, node);
         }
 
